aboutsummaryrefslogtreecommitdiff
path: root/src/tool_operate.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/tool_operate.c')
-rw-r--r--src/tool_operate.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/tool_operate.c b/src/tool_operate.c
index 25aa9413d..6458c11a9 100644
--- a/src/tool_operate.c
+++ b/src/tool_operate.c
@@ -1831,14 +1831,14 @@ CURLcode operate(struct GlobalConfig *config, int argc, argv_item_t argv[])
operation = operation->next;
}
- /* Reset the operation pointer */
- operation = config->first;
+ /* Set the current operation pointer */
+ config->current = config->first;
/* Perform each operation */
- while(!result && operation) {
- result = operate_do(operation);
+ while(!result && config->current) {
+ result = operate_do(config->current);
- operation = operation->next;
+ config->current = config->current->next;
}
}
}